import sys
import numpy as np
from distutils.extension import Extension


if sys.platform == 'win32':
    extra_compile_args = ['/openmp']
    extra_link_args = None
else:
    # linux
    extra_compile_args = ['-fopenmp']
    extra_link_args = ['-fopenmp']

def make_ext(modname, sources, **kwargs):
    if not isinstance(sources, list):
        sources = [sources]
    return Extension(modname,
    sources=sources,
    extra_compile_args=extra_compile_args,
    extra_link_args=extra_link_args,
    include_dirs=[np.get_include()],
    #define_macros=[('CYTHON_TRACE', '1')],
    **kwargs
    )



import re
import os

def get_version(package_name: str,
                setupfilepath: str,
                package_dir:str = 'src',
                versionfile:str ='_version.py'):
    """
    Parse the version number from a version file

    Parameters
    ----------

    """
    folder = os.path.join(os.path.dirname(setupfilepath), package_dir)
    version_path= os.path.join(folder, package_name, versionfile)
    try:
        verstrline = open(version_path, "rt").read()
    except IOError:
        raise IOError('Version file {} not found'.format(version_path))
    VSRE = r"^__version__ = ['\"]([^'\"]*)['\"]"
    mo = re.search(VSRE, verstrline, re.M)
    if mo:
        verstr = mo.group(1)
    else:
        raise RuntimeError(
            "Unable to find version string in {}.".format(version_path,))
    return verstr


# -*- coding: utf-8 -*-

from setuptools import setup, find_packages
import os

version_dict = dict()
exec(open(os.path.join(os.path.dirname(__file__),
                       'src',
                       "cythoninstallhelpers",
                       '_version.py')).read(),
     version_dict)

setup(
    name="cythoninstallhelpers",
    version=version_dict['__version__'],
    description="helper for cython installation",
    url='https://maxbo.github.io/cythonarrays/',
    author='Max Bohnet',
    author_email='bohnet@ggr-planung.de',
    classifiers=[
        # How mature is this project? Common values are
        'Development Status :: 5 - Production/Stable',

        # Indicate who your project is intended for
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Build Tools',

        # Pick your license as you wish (should match "license" above)
         'License :: OSI Approved :: GNU General Public License v3 or later (GPLv3+)',

        # Specify the Python versions you support here. In particular, ensure
        # that you indicate whether you support Python 2, Python 3 or both.
        'Programming Language :: Python',
        'Programming Language :: Cython',

    ],
    keywords='cython setuptools',

    packages=find_packages('src', exclude=['ez_setup']),

    package_dir={'': 'src'},
    package_data={'': ['*.pxd']},
    include_package_data=True,
    zip_safe=False,
    data_files=[],
    install_requires=[
        #'setuptools',
        ],
)




# -*- coding: utf-8 -*-

import os
import sys
import numpy as np
from Cython.Build import cythonize

from .build_config import (extra_compile_args,
                          extra_link_args,
                          make_ext,)


def make_extensions(ext_modnames, further_args={}):
    """
    add sources to the ext_modules specified in the input list

    Parameters
    ----------
    ext_modnames : list of str
        the extension modules to create
    further_args : dict with further arguments for extension module

    Returns
    -------
    extensions : list of Extension-instances
    """
    extensions = []


    suffix = '.pyx'
    for modname in ext_modnames:
        mn = modname.split('.')
        pyxfilename = os.path.join('src', *mn) + suffix
        sources = [pyxfilename]
        further_arg = further_args.get(modname, {})
        if further_arg:
            more_sources = further_arg.pop('sources')
            ms = mn[:-1]
            full_more_sources = []
            for source in more_sources:
                full_source = ['src'] + ms + [source]
                full_more_sources.append(os.sep.join(full_source))
            sources.extend(full_more_sources)
        extension = make_ext(modname, sources, **further_arg)
        extensions.append(extension)

    cython_extensions = cythonize(extensions, annotate=True)
    return cython_extensions